==> aws-cdk-lib-2.214.0-sources.jar: software/amazon/awscdk/services/cloudfront/origins/FunctionUrlOrigin.java <==
package software.amazon.awscdk.services.cloudfront.origins;

/**
 * An Origin for a Lambda Function URL.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * import software.amazon.awscdk.services.lambda.*;
 * Function fn;
 * FunctionUrl fnUrl = fn.addFunctionUrl(FunctionUrlOptions.builder()
 *         .authType(FunctionUrlAuthType.AWS_IAM)
 *         .build());
 * Distribution.Builder.create(this, "MyDistribution")
 *         .defaultBehavior(BehaviorOptions.builder()
 *                 .origin(FunctionUrlOrigin.withOriginAccessControl(fnUrl))
 *                 .build())
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.113.0 (build fc68b25)", date = "2025-09-02T11:25:27.934Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_cloudfront_origins.FunctionUrlOrigin")
public class FunctionUrlOrigin extends software.amazon.awscdk.services.cloudfront.OriginBase {

    protected FunctionUrlOrigin(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected FunctionUrlOrigin(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param lambdaFunctionUrl This parameter is required.
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public FunctionUrlOrigin(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.IFunctionUrl lambdaFunctionUrl, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.cloudfront.origins.FunctionUrlOriginProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(lambdaFunctionUrl, "lambdaFunctionUrl is required"), props });
    }

    /**
     * @param lambdaFunctionUrl This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public FunctionUrlOrigin(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.IFunctionUrl lambdaFunctionUrl) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(lambdaFunctionUrl, "lambdaFunctionUrl is required") });
    }

    /**
     * Create a Lambda Function URL Origin with Origin Access Control (OAC) configured.
     * <p>
     * @param lambdaFunctionUrl This parameter is required.
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudfront.IOrigin withOriginAccessControl(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.IFunctionUrl lambdaFunctionUrl, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.cloudfront.origins.FunctionUrlOriginWithOACProps props) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.cloudfront.origins.FunctionUrlOrigin.class, "withOriginAccessControl", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.IOrigin.class), new Object[] { java.util.Objects.requireNonNull(lambdaFunctionUrl, "lambdaFunctionUrl is required"), props });
    }

    /**
     * Create a Lambda Function URL Origin with Origin Access Control (OAC) configured.
     * <p>
     * @param lambdaFunctionUrl This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudfront.IOrigin withOriginAccessControl(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.IFunctionUrl lambdaFunctionUrl) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.cloudfront.origins.FunctionUrlOrigin.class, "withOriginAccessControl", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.IOrigin.class), new Object[] { java.util.Objects.requireNonNull(lambdaFunctionUrl, "lambdaFunctionUrl is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    protected @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.cloudfront.CfnDistribution.CustomOriginConfigProperty renderCustomOriginConfig() {
        return software.amazon.jsii.Kernel.call(this, "renderCustomOriginConfig", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.CfnDistribution.CustomOriginConfigProperty.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.cloudfront.origins.FunctionUrlOrigin}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.cloudfront.origins.FunctionUrlOrigin> {
        /**
         * @return a new instance of {@link Builder}.
         * @param lambdaFunctionUrl This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.amazon.awscdk.services.lambda.IFunctionUrl lambdaFunctionUrl) {
            return new Builder(lambdaFunctionUrl);
        }

        private final software.amazon.awscdk.services.lambda.IFunctionUrl lambdaFunctionUrl;
        private software.amazon.awscdk.services.cloudfront.origins.FunctionUrlOriginProps.Builder props;

        private Builder(final software.amazon.awscdk.services.lambda.IFunctionUrl lambdaFunctionUrl) {
            this.lambdaFunctionUrl = lambdaFunctionUrl;
        }

        /**
         * The number of times that CloudFront attempts to connect to the origin;
         * <p>
         * valid values are 1, 2, or 3 attempts.
         * <p>
         * Default: 3
         * <p>
         * @return {@code this}
         * @param connectionAttempts The number of times that CloudFront attempts to connect to the origin;. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder connectionAttempts(final java.lang.Number connectionAttempts) {
            this.props().connectionAttempts(connectionAttempts);
            return this;
        }

        /**
         * The number of seconds that CloudFront waits when trying to establish a connection to the origin.
         * <p>
         * Valid values are 1-10 seconds, inclusive.
         * <p>
         * Default: Duration.seconds(10)
         * <p>
         * @return {@code this}
         * @param connectionTimeout The number of seconds that CloudFront waits when trying to establish a connection to the origin. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder connectionTimeout(final software.amazon.awscdk.Duration connectionTimeout) {
            this.props().connectionTimeout(connectionTimeout);
            return this;
        }

        /**
         * A list of HTTP header names and values that CloudFront adds to requests it sends to the origin.
         * <p>
         * Default: {}
         * <p>
         * @return {@code this}
         * @param customHeaders A list of HTTP header names and values that CloudFront adds to requests it sends to the origin. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder customHeaders(final java.util.Map<java.lang.String, java.lang.String> customHeaders) {
            this.props().customHeaders(customHeaders);
            return this;
        }

        /**
         * The unique identifier of an origin access control for this origin.
         * <p>
         * Default: - no origin access control
         * <p>
         * @return {@code this}
         * @param originAccessControlId The unique identifier of an origin access control for this origin. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder originAccessControlId(final java.lang.String originAccessControlId) {
            this.props().originAccessControlId(originAccessControlId);
            return this;
        }

        /**
         * A unique identifier for the origin.
         * <p>
         * This value must be unique within the distribution.
         * <p>
         * Default: - an originid will be generated for you
         * <p>
         * @return {@code this}
         * @param originId A unique identifier for the origin. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder originId(final java.lang.String originId) {
            this.props().originId(originId);
            return this;
        }

        /**
         * Origin Shield is enabled by setting originShieldRegion to a valid region, after this to disable Origin Shield again you must set this flag to false.
         * <p>
         * Default: - true
         * <p>
         * @return {@code this}
         * @param originShieldEnabled Origin Shield is enabled by setting originShieldRegion to a valid region, after this to disable Origin Shield again you must set this flag to false. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder originShieldEnabled(final java.lang.Boolean originShieldEnabled) {
            this.props().originShieldEnabled(originShieldEnabled);
            return this;
        }

        /**
         * When you enable Origin Shield in the AWS Region that has the lowest latency to your origin, you can get better network performance.
         * <p>
         * Default: - origin shield not enabled
         * <p>
         * @return {@code this}
         * @see <a href="https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/origin-shield.html">https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/origin-shield.html</a>
         * @param originShieldRegion When you enable Origin Shield in the AWS Region that has the lowest latency to your origin, you can get better network performance. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder originShieldRegion(final java.lang.String originShieldRegion) {
            this.props().originShieldRegion(originShieldRegion);
            return this;
        }

        /**
         * An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin.
         * <p>
         * Must begin, but not end, with '/' (e.g., '/production/images').
         * <p>
         * Default: '/'
         * <p>
         * @return {@code this}
         * @param originPath An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder originPath(final java.lang.String originPath) {
            this.props().originPath(originPath);
            return this;
        }

        /**
         * Specifies how long, in seconds, CloudFront persists its connection to the origin.
         * <p>
         * The valid range is from 1 to 180 seconds, inclusive.
         * <p>
         * Note that values over 60 seconds are possible only after a limit increase request for the origin response timeout quota
         * has been approved in the target account; otherwise, values over 60 seconds will produce an error at deploy time.
         * <p>
         * Default: Duration.seconds(5)
         * <p>
         * @return {@code this}
         * @param keepaliveTimeout Specifies how long, in seconds, CloudFront persists its connection to the origin. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder keepaliveTimeout(final software.amazon.awscdk.Duration keepaliveTimeout) {
            this.props().keepaliveTimeout(keepaliveTimeout);
            return this;
        }

        /**
         * Specifies how long, in seconds, CloudFront waits for a response from the origin.
         * <p>
         * The valid range is from 1 to 180 seconds, inclusive.
         * <p>
         * Note that values over 60 seconds are possible only after a limit increase request for the origin response timeout quota
         * has been approved in the target account; otherwise, values over 60 seconds will produce an error at deploy time.
         * <p>
         * Default: Duration.seconds(30)
         * <p>
         * @return {@code this}
         * @param readTimeout Specifies how long, in seconds, CloudFront waits for a response from the origin. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder readTimeout(final software.amazon.awscdk.Duration readTimeout) {
            this.props().readTimeout(readTimeout);
            return this;
        }

        /**
         * @return a newly built instance of {@link software.amazon.awscdk.services.cloudfront.origins.FunctionUrlOrigin}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.cloudfront.origins.FunctionUrlOrigin build() {
            return new software.amazon.awscdk.services.cloudfront.origins.FunctionUrlOrigin(
                this.lambdaFunctionUrl,
                this.props != null ? this.props.build() : null
            );
        }

        private software.amazon.awscdk.services.cloudfront.origins.FunctionUrlOriginProps.Builder props() {
            if (this.props == null) {
                this.props = new software.amazon.awscdk.services.cloudfront.origins.FunctionUrlOriginProps.Builder();
            }
            return this.props;
        }
    }
}

==> aws-cdk-lib-2.223.0-sources.jar: software/amazon/awscdk/services/cloudfront/origins/FunctionUrlOrigin.java <==
package software.amazon.awscdk.services.cloudfront.origins;

/**
 * An Origin for a Lambda Function URL.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * import software.amazon.awscdk.services.lambda.*;
 * Function fn;
 * FunctionUrl fnUrl = fn.addFunctionUrl(FunctionUrlOptions.builder().authType(FunctionUrlAuthType.NONE).build());
 * Distribution.Builder.create(this, "Distribution")
 *         .defaultBehavior(BehaviorOptions.builder()
 *                 .origin(FunctionUrlOrigin.Builder.create(fnUrl)
 *                         .readTimeout(Duration.seconds(30))
 *                         .responseCompletionTimeout(Duration.seconds(90))
 *                         .keepaliveTimeout(Duration.seconds(45))
 *                         .build())
 *                 .build())
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.118.0 (build 02eec31)", date = "2025-11-10T13:40:00.296Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_cloudfront_origins.FunctionUrlOrigin")
public class FunctionUrlOrigin extends software.amazon.awscdk.services.cloudfront.OriginBase {

    protected FunctionUrlOrigin(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected FunctionUrlOrigin(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param lambdaFunctionUrl This parameter is required.
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public FunctionUrlOrigin(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.IFunctionUrl lambdaFunctionUrl, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.cloudfront.origins.FunctionUrlOriginProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(lambdaFunctionUrl, "lambdaFunctionUrl is required"), props });
    }

    /**
     * @param lambdaFunctionUrl This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public FunctionUrlOrigin(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.IFunctionUrl lambdaFunctionUrl) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(lambdaFunctionUrl, "lambdaFunctionUrl is required") });
    }

    /**
     * Create a Lambda Function URL Origin with Origin Access Control (OAC) configured.
     * <p>
     * @param lambdaFunctionUrl This parameter is required.
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudfront.IOrigin withOriginAccessControl(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.IFunctionUrl lambdaFunctionUrl, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.cloudfront.origins.FunctionUrlOriginWithOACProps props) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.cloudfront.origins.FunctionUrlOrigin.class, "withOriginAccessControl", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.IOrigin.class), new Object[] { java.util.Objects.requireNonNull(lambdaFunctionUrl, "lambdaFunctionUrl is required"), props });
    }

    /**
     * Create a Lambda Function URL Origin with Origin Access Control (OAC) configured.
     * <p>
     * @param lambdaFunctionUrl This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudfront.IOrigin withOriginAccessControl(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.IFunctionUrl lambdaFunctionUrl) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.cloudfront.origins.FunctionUrlOrigin.class, "withOriginAccessControl", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.IOrigin.class), new Object[] { java.util.Objects.requireNonNull(lambdaFunctionUrl, "lambdaFunctionUrl is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    protected @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.cloudfront.CfnDistribution.CustomOriginConfigProperty renderCustomOriginConfig() {
        return software.amazon.jsii.Kernel.call(this, "renderCustomOriginConfig", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.CfnDistribution.CustomOriginConfigProperty.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.cloudfront.origins.FunctionUrlOrigin}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.cloudfront.origins.FunctionUrlOrigin> {
        /**
         * @return a new instance of {@link Builder}.
         * @param lambdaFunctionUrl This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.amazon.awscdk.services.lambda.IFunctionUrl lambdaFunctionUrl) {
            return new Builder(lambdaFunctionUrl);
        }

        private final software.amazon.awscdk.services.lambda.IFunctionUrl lambdaFunctionUrl;
        private software.amazon.awscdk.services.cloudfront.origins.FunctionUrlOriginProps.Builder props;

        private Builder(final software.amazon.awscdk.services.lambda.IFunctionUrl lambdaFunctionUrl) {
            this.lambdaFunctionUrl = lambdaFunctionUrl;
        }

        /**
         * The number of times that CloudFront attempts to connect to the origin;
         * <p>
         * valid values are 1, 2, or 3 attempts.
         * <p>
         * Default: 3
         * <p>
         * @return {@code this}
         * @param connectionAttempts The number of times that CloudFront attempts to connect to the origin;. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder connectionAttempts(final java.lang.Number connectionAttempts) {
            this.props().connectionAttempts(connectionAttempts);
            return this;
        }

        /**
         * The number of seconds that CloudFront waits when trying to establish a connection to the origin.
         * <p>
         * Valid values are 1-10 seconds, inclusive.
         * <p>
         * Default: Duration.seconds(10)
         * <p>
         * @return {@code this}
         * @param connectionTimeout The number of seconds that CloudFront waits when trying to establish a connection to the origin. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder connectionTimeout(final software.amazon.awscdk.Duration connectionTimeout) {
            this.props().connectionTimeout(connectionTimeout);
            return this;
        }

        /**
         * A list of HTTP header names and values that CloudFront adds to requests it sends to the origin.
         * <p>
         * Default: {}
         * <p>
         * @return {@code this}
         * @param customHeaders A list of HTTP header names and values that CloudFront adds to requests it sends to the origin. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder customHeaders(final java.util.Map<java.lang.String, java.lang.String> customHeaders) {
            this.props().customHeaders(customHeaders);
            return this;
        }

        /**
         * The unique identifier of an origin access control for this origin.
         * <p>
         * Default: - no origin access control
         * <p>
         * @return {@code this}
         * @param originAccessControlId The unique identifier of an origin access control for this origin. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder originAccessControlId(final java.lang.String originAccessControlId) {
            this.props().originAccessControlId(originAccessControlId);
            return this;
        }

        /**
         * A unique identifier for the origin.
         * <p>
         * This value must be unique within the distribution.
         * <p>
         * Default: - an originid will be generated for you
         * <p>
         * @return {@code this}
         * @param originId A unique identifier for the origin. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder originId(final java.lang.String originId) {
            this.props().originId(originId);
            return this;
        }

        /**
         * Origin Shield is enabled by setting originShieldRegion to a valid region, after this to disable Origin Shield again you must set this flag to false.
         * <p>
         * Default: - true
         * <p>
         * @return {@code this}
         * @param originShieldEnabled Origin Shield is enabled by setting originShieldRegion to a valid region, after this to disable Origin Shield again you must set this flag to false. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder originShieldEnabled(final java.lang.Boolean originShieldEnabled) {
            this.props().originShieldEnabled(originShieldEnabled);
            return this;
        }

        /**
         * When you enable Origin Shield in the AWS Region that has the lowest latency to your origin, you can get better network performance.
         * <p>
         * Default: - origin shield not enabled
         * <p>
         * @return {@code this}
         * @see <a href="https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/origin-shield.html">https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/origin-shield.html</a>
         * @param originShieldRegion When you enable Origin Shield in the AWS Region that has the lowest latency to your origin, you can get better network performance. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder originShieldRegion(final java.lang.String originShieldRegion) {
            this.props().originShieldRegion(originShieldRegion);
            return this;
        }

        /**
         * The time that a request from CloudFront to the origin can stay open and wait for a response.
         * <p>
         * If the complete response isn't received from the origin by this time, CloudFront ends the connection.
         * <p>
         * Valid values are 1-3600 seconds, inclusive.
         * <p>
         * Default: undefined -  AWS CloudFront default is not enforcing a maximum value
         * <p>
         * @return {@code this}
         * @see <a href="https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/DownloadDistValuesOrigin.html#response-completion-timeout">https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/DownloadDistValuesOrigin.html#response-completion-timeout</a>
         * @param responseCompletionTimeout The time that a request from CloudFront to the origin can stay open and wait for a response. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder responseCompletionTimeout(final software.amazon.awscdk.Duration responseCompletionTimeout) {
            this.props().responseCompletionTimeout(responseCompletionTimeout);
            return this;
        }

        /**
         * An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin.
         * <p>
         * Must begin, but not end, with '/' (e.g., '/production/images').
         * <p>
         * Default: '/'
         * <p>
         * @return {@code this}
         * @param originPath An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder originPath(final java.lang.String originPath) {
            this.props().originPath(originPath);
            return this;
        }

        /**
         * Specifies which IP protocol CloudFront uses when connecting to your origin.
         * <p>
         * If your origin uses both IPv4 and IPv6 protocols, you can choose dualstack to help optimize reliability.
         * <p>
         * Default: OriginIpAddressType.IPV4
         * <p>
         * @return {@code this}
         * @param ipAddressType Specifies which IP protocol CloudFront uses when connecting to your origin. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ipAddressType(final software.amazon.awscdk.services.cloudfront.OriginIpAddressType ipAddressType) {
            this.props().ipAddressType(ipAddressType);
            return this;
        }

        /**
         * Specifies how long, in seconds, CloudFront persists its connection to the origin.
         * <p>
         * The valid range is from 1 to 180 seconds, inclusive.
         * <p>
         * Note that values over 60 seconds are possible only after a limit increase request for the origin response timeout quota
         * has been approved in the target account; otherwise, values over 60 seconds will produce an error at deploy time.
         * <p>
         * Default: Duration.seconds(5)
         * <p>
         * @return {@code this}
         * @param keepaliveTimeout Specifies how long, in seconds, CloudFront persists its connection to the origin. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder keepaliveTimeout(final software.amazon.awscdk.Duration keepaliveTimeout) {
            this.props().keepaliveTimeout(keepaliveTimeout);
            return this;
        }

        /**
         * Specifies how long, in seconds, CloudFront waits for a response from the origin.
         * <p>
         * The valid range is from 1 to 180 seconds, inclusive.
         * <p>
         * Note that values over 60 seconds are possible only after a limit increase request for the origin response timeout quota
         * has been approved in the target account; otherwise, values over 60 seconds will produce an error at deploy time.
         * <p>
         * Default: Duration.seconds(30)
         * <p>
         * @return {@code this}
         * @param readTimeout Specifies how long, in seconds, CloudFront waits for a response from the origin. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder readTimeout(final software.amazon.awscdk.Duration readTimeout) {
            this.props().readTimeout(readTimeout);
            return this;
        }

        /**
         * @return a newly built instance of {@link software.amazon.awscdk.services.cloudfront.origins.FunctionUrlOrigin}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.cloudfront.origins.FunctionUrlOrigin build() {
            return new software.amazon.awscdk.services.cloudfront.origins.FunctionUrlOrigin(
                this.lambdaFunctionUrl,
                this.props != null ? this.props.build() : null
            );
        }

        private software.amazon.awscdk.services.cloudfront.origins.FunctionUrlOriginProps.Builder props() {
            if (this.props == null) {
                this.props = new software.amazon.awscdk.services.cloudfront.origins.FunctionUrlOriginProps.Builder();
            }
            return this.props;
        }
    }
}
